# OpenFeature Community

<details>
<summary>
Table of Contents
</summary>

- [Getting Involved](#getting-involved)
- [Contributing](#contributing)
  - [Contributing Prerequisites (DCO)](#contributing-prerequisites-dco)
- [Governing Bodies](#governing-bodies)
  - [Interested Parties](#interested-parties)
- [Communication](#communication)
  - [Discussions](#discussions)
  - [Community Meetings](#community-meetings)
  - [Social Media](#social-media)
  - [Mailing List](#mailing-list)
- [Roadmap](#roadmap)
- [License](#license)
- [Logos and Brand Guide](#logos-and-brand-guide)
- [Special Interest Groups](#special-interest-groups)
- [Associated Components and Implementations](#associated-components-and-implementations)
- [Adopters](#adopters)
- [Code of Conduct](#code-of-conduct)

</details>

## Getting Involved

If you are interested in being informed about the project or contributing, feel free to add yourself and/or your organization to [Interested Parties](./interested-parties.md).

## Contributing

All contributors are welcome!
Please see the contributing guidelines
[here](https://github.com/open-feature/.github/blob/main/CONTRIBUTING.md).

### Contributing Prerequisites (DCO)

The [Cloud Native Computing Foundation (CNCF)](https://www.cncf.io/) requires all pull requests to be signed off using [Developer Certificate of Origin (DCO)](https://wiki.linuxfoundation.org/dco).
By submitting pull requests, submitters acknowledge they grant the [Apache License v2](./LICENSE) to the code and are eligible to grant this license for all commits submitted in their pull requests.

## Governing Bodies

- Governance Committee (GC): [Charter](./governance-charter.md), [Members](./community-members.md#governance-board)
- Technical Committee (TC): [Charter](./tech-committee-charter.md), [Members](./community-members.md#technical-committee)

### Interested Parties

If you are interested in being informed about the project or contributing, feel free to add yourself and/or your organization to [Interested Parties](./interested-parties.md).

## Communication

### Discussions

For those who are brand new to OpenFeature and want to chat or get redirected to the appropriate place for a specific question, feel free to join [the CNCF OpenFeature Slack channel](https://cloud-native.slack.com/archives/C0344AANLA1). If you are new, you can create a CNCF Slack account [here](https://slack.cncf.io/).

### Community Meetings

| Name                          | Meeting Time                        | Meeting Notes                                                                                                  | Discussions                                                                                                             |
| ----------------------------- | ----------------------------------- | -------------------------------------------------------------------------------------------------------------- | ----------------------------------------------------------------------------------------------------------------------- |
| OpenFeature Community Meeting | Every other Thursday at 10:00 am ET | [Google Doc](https://docs.google.com/document/d/1pp6t2giTcdEdVAri_2B1Z6Mv8mHhvtZT1AmkPV9K7xQ/edit?usp=sharing) | [Zoom](https://zoom-lfx.platform.linuxfoundation.org/meeting/96167755909?password=212f416d-85a3-4f2f-ad15-2d7d4ca43578) |

All upcoming OpenFeature meetings and events are on our [public calendar](https://zoom-lfx.platform.linuxfoundation.org/meetings/openfeature?view=week).

### Social Media

Follow us on social media and help us to spread the word!
Please use the `#openfeature` hashtag or mention our accounts when you share the content.

- BlueSky: [OpenFeature](https://bsky.app/profile/openfeature.dev)
- Twitter: [@openfeature](https://twitter.com/openfeature)
- LinkedIn: [OpenFeature](https://www.linkedin.com/company/openfeature/)
- YouTube: [OpenFeature](https://youtube.com/@openfeature/)

### Mailing List

Join our (low-traffic) [CNCF mailing list](https://lists.cncf.io/g/cncf-openfeature-project) to stay up to date on announcements, discussions, and more.

## Roadmap

The project roadmap is available [here](https://github.com/orgs/open-feature/projects/1).
New initiatives require an accepted [OpenFeature Enhancement Proposal (OFEP)](https://github.com/open-feature/ofep). A community decision will then be made as documented in [Decision Making](./governance-charter.md#decision-making).

## License

All OpenFeature projects are shipped under the permissive [Apache License v2](./LICENSE) as CNCF IP Policy dictates. [This blog post](https://www.cncf.io/blog/2017/02/01/cncf-recommends-aslv2/) explains the reasoning behind choosing this license. Refer to [CONTRIBUTING.md](https://github.com/open-feature/.github/blob/main/CONTRIBUTING.md) for details on code attribution.

## Logos and Brand Guide

The OpenFeature logos and brand guide can be found in the [branding guidelines](./branding-guidelines.md).

## Special Interest Groups

You can find us in the `#openfeature` channel on the CNCF Slack Workspace. You can join the CNCF Slack Workspace by registering [here](https://slack.cncf.io).

Notes and recordings from previous meetings can be found below:

- [Meeting notes](https://docs.google.com/document/d/1pp6t2giTcdEdVAri_2B1Z6Mv8mHhvtZT1AmkPV9K7xQ/edit?usp=sharing)
- [Recordings](https://www.youtube.com/channel/UCXSFt-dT2HORGXz1-ksxtxw)
- [CNCF Hosted Project Community Chapter](https://community.cncf.io/openfeature/)

## Associated Components and Implementations

The OpenFeature specification defines abstractions and interfaces for the purposes of flexibly integrating with various feature flag management systems, as well as with tools related to feature flag evaluation (such as telemetry and logging). In order to maintain [neutrality and no/low dependencies](https://github.com/open-feature/spec#design-principles), implementations of these abstractions should not be included in SDKs. Such implementations may exist in the "contribs" repository for their respective language (ie: https://github.com/open-feature/js-sdk-contrib) or in other repositories not owned by the OpenFeature organization. We recommend implementations be open source, but that's not a requirement.

## Adopters

Please refer to [Adopters list](./ADOPTERS.md)

## Code of Conduct

We as members, contributors, and leaders pledge to make participation in our community a harassment-free experience for everyone, regardless of age, body size, visible or invisible disability, ethnicity, sex characteristics, gender identity and expression, level of experience, education, socio-economic status, nationality, personal appearance, race, caste, color, religion, or sexual identity and orientation. We pledge to act and interact in ways that contribute to an open, welcoming, diverse, inclusive, and healthy community.

The project and its community abide by [the Code of Conduct](https://github.com/open-feature/.github/blob/main/CODE_OF_CONDUCT.md).
This Code of Conduct is adapted from the [Contributor Covenant](https://www.contributor-covenant.org),
version 2.1, available
[here](https://www.contributor-covenant.org/version/2/1/code_of_conduct.html).

testing
