# Governance Charter

## Overview

This document describes the governance process under which the project operates.
It describes the election process for the _Governance Committee_ (GC) and how the committee operates.

## Goals

The role of the _Governance Committee_ is to be a live, responsive
body that can refactor and reform as necessary to adapt to a changing project
and community.

## Governance Committee

The _Governance Committee_ is responsible for representing the project,
making a final decision if a consensus cannot be reached (see _Decision Making_),
handling the Code of Conduct escalations,
defining and approving with the project members the final governance model,
and organizing elections for the elected governance board body.

### Governance Committee Members

[Governance Committee Members](./community-members.md#governance-board)

## Decision making

Decisions are made by a consensus of _Project Members_ and [Interested Parties](./interested-parties.md).
If this consensus cannot be reached,
the decision can be made by the plain majority vote of _Governance Committee_ members.

Key discussions and decisions should happen asynchronously in communication channels like GitHub Issues, discussions or pull requests.
Technical decisions are expected to be documented in the
[OpenFeature Specification](https://github.com/open-feature/spec).
The community decisions should be documented in this Governance repository.

## Meetings

The project conducts [regular project meetings](https://github.com/open-feature/community#meetings-and-events)
hosted by its maintainers and contributors.
These meetings are used as additional discussion and consensus building
but not for making decisions without prior discussion in async channels.

#### Governance Committee Members

_Governance Committee_ members are responsible for representing the project in communications with organizations,
including but not limited to contributor companies, adopters, vendors and foundations.
Apart from the representative role,
they can make a final decision when a consensus cannot be reached.
Each company/organization should have less than 50% of the seats.

## Elections

### Members

People which are part of the GitHub Organization are considered as members and are eligible to vote.

### Eligibility for candidacy

Anyone may nominate either themselves or someone else to be a candidate in the
election. To be ratified as a candidate, the nominee must accept the nomination
and three Members (including the nominator, if they are a member)
from three different employers, must endorse the nomination.

Nominators are free to nominate as many people as they wish to. Members
may endorse multiple nominees, but we expect endorsements to be in good
faith. If this turns out to be a problem, this will be reconsidered.

### Eligibility for voting

All organization members are eligible to vote for the _Governance Committee_ members. 

### Election process

Elections will be held using time-limited approval voting on
[Helios](https://vote.heliosvoting.org/). The top vote getters will be elected
to the respective positions.

### Maximal representation

To encourage diversity there will be a maximum of one-third representation on
the _Governance Committee_ from any one company at any time. If the outcomes of
an election result in greater than 1/3 representation (or maximum of two,
whichever is greater), the lowest vote getters from any particular company will
be removed until representation on the committee is equal or less than one-third.

If percentages shift because of job changes, acquisitions, or other events,
sufficient members of the committee must resign until max one-third
representation is achieved. If it is impossible to find sufficient members to
resign, the entire company’s representation will be removed and new special
elections held. In the event of a question of company membership (for example
evaluating independence of corporate subsidiaries) a majority of all
non-involved _Governance Committee_ members will decide. 

### Initial Election

The bootstrap committee will operate the election and circulate a timeline for
nominations, and the vote.

### Special Elections

In the event of a resignation or other loss of a _Governance Committee_ member, a
special election for that position will be held as soon as possible. The same
group of people as described in "eligibility for voting" will vote in the
special election. A committee member elected in a special election will serve
out the remainder of the term for the person they are replacing, regardless of
the length of that remainder.

### Limiting Corporate Campaigning Support

To reduce the size of company advantages, candidates may not use their companies
internal or external brand to campaign. Their employers cannot solicit votes on
their behalf or sponsor candidates from partner organizations. Simply put,
elections highlight individuals outside of their corporate role and should be
treated as "brand free" activities.

## Refactoring or reforming the governance committee

At any time the _Governance Committee_ may vote, via supermajority (greater than
two-thirds of votes), to rewrite or remove any part of this charter. Beyond
small tweaks, this should be used sparingly, if ever, and in the presence of
clear failures of the process. We explicitly do not allocate a role for the
broader community in reformulating governance, we believe that in such a case
the community will "vote with their feet" by either leaving or forking the
project.

## Inactivity

It is important for _Governance Committee_ to be and stay active to set an example and show commitment to the project. Inactivity is harmful to the project as it may lead to unexpected delays, contributor attrition, and a lost of trust in the project.

- Inactivity is measured by:
  - Periods of no contributions for longer than 3 months
  - Periods of no communication for longer than 3 months
- Consequences of being inactive include:
  - Involuntary removal or demotion
  - Being asked to move to Emeritus status

## Involuntary Removal or Demotion

Involuntary removal/demotion of a _Governance Committee_ happens when responsibilities and requirements aren't being met. This may include repeated patterns of inactivity, extended period of inactivity, a period of failing to meet the requirements of your role, and/or a violation of the Code of Conduct. This process is important because it protects the community and its deliverables while also opens up opportunities for new people to step in.

Involuntary removal or demotion is handled through a vote by a majority of the current _Governance Committee_.

## Stepping Down/Emeritus Process

If and when _Governance Committee_ members commitment levels change, they can consider stepping down (moving down the contributor ladder) vs moving to emeritus status (completely stepping away from the project).

Contact the _Governance Committee_ about changing to Emeritus status, or stepping down.

Members of the _Governance Committee_ will graduate to becoming *Emeritus* members
of the _Governance Committee_ once their term ends.

## Contact

- For inquiries, please reach out to:
  - members of the [Governance Committee](https://github.com/open-feature/community/blob/main/community-members.md#governance-board)


